@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: m3Func.php 1404 2008-12-31 15:00:32Z fishbone $
+ * @version    SVN: $Id: m3Func.php 1490 2009-01-30 10:58:01Z fishbone $
  * @link       http://www.magic3.org
  */
 /**
@@ -102,6 +102,24 @@ function makePassword($len, $str = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGH
 	}
 	return $pwd;
 }
+/**
+ * 省略文字列を作成
+ *
+ * @param string  $str		変換元文字列
+ * @param int     $len		文字列長
+ * @return string			作成した文字列
+ */
+function makeTruncStr($str, $len)
+{
+	if (function_exists('mb_substr')){
+		if (mb_strlen($str) > $len) $addStr = '…';
+		$destStr = mb_substr($str, 0, $len) . $addStr;
+	} else {
+		if (strlen($str) > $len) $addStr = '...';
+		$destStr = substr($str, 0, $len) . $addStr;
+	}
+	return $destStr;
+}
 /**
  * メールアドレスの取り出し
  *
