@@ -12,7 +12,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: pageManager.php 1591 2009-03-19 02:09:32Z fishbone $
+ * @version    SVN: $Id: pageManager.php 1624 2009-03-23 10:29:18Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/common/core.php');
@@ -93,6 +93,7 @@ class PageManager extends Core
 	const LIB_JQUERY_BGIFRAME		= 'jquery.bgiframe';
 	const LIB_JQUERY_HOVERINTENT	= 'jquery.hoverintent';
 	const LIB_JQUERY_TABLEDND		= 'jquery.tablednd';
+	const LIB_JQUERY_SIMPLEMODAL	= 'jquery.simplemodal';
 	
 	const LIB_JQUERY_UI			= 'jquery-ui';
 	const LIB_JQUERY_UI_PLUS	= 'jquery-ui-plus';
@@ -118,6 +119,7 @@ class PageManager extends Core
 	const JQUERY_HOVERINTENT_FILENAME	= 'jquery/jquery.hoverIntent.min.js';
 	const JQUERY_TABLEDND_FILENAME		= 'jquery/jquery.tablednd_0_5.js';
 	const JQUERY_TABLEDND_CSS			= 'jquery/jquery.tablednd.css';
+	const JQUERY_SIMPLEMODAL_FILENAME	= 'jquery/jquery.simplemodal-1.2.3.pack.js';
 	
 	// ファイル名
 	const JQUERY_FILENAME			= 'jquery-1.2.6.pack.js';						// JQuery
@@ -190,7 +192,8 @@ class PageManager extends Core
 								self::LIB_JQUERY_BGIFRAME		=>	array(	'script' => array(self::JQUERY_BGIFRAME_FILENAME)),	// jquery.bgiframe用のファイル
 								self::LIB_JQUERY_HOVERINTENT	=>	array(	'script' => array(self::JQUERY_HOVERINTENT_FILENAME)),
 								self::LIB_JQUERY_TABLEDND		=>	array(	'script' => array(self::JQUERY_TABLEDND_FILENAME),	// jquery.tablednd用のファイル
-																			'css'	=> array(self::JQUERY_TABLEDND_CSS)));
+																			'css'	=> array(self::JQUERY_TABLEDND_CSS)),
+								self::LIB_JQUERY_SIMPLEMODAL		=>	array(	'script' => array(self::JQUERY_SIMPLEMODAL_FILENAME)));			// jquery.simplemodal用のファイル
 
 		// 遅延ウィジェットリスト									
 		$this->lateLaunchWidgetList = array();
