@@ -9,7 +9,7 @@
 -- * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 -- * @copyright  Copyright 2006-2008 Magic3 Project.
 -- * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
--- * @version    SVN: $Id: create_ec.sql 1459 2009-01-22 10:31:03Z fishbone $
+-- * @version    SVN: $Id: create_ec.sql 1585 2009-03-16 04:28:02Z fishbone $
 -- * @link       http://www.magic3.org
 -- *
 -- --------------------------------------------------------------------------------------------------
@@ -59,6 +59,8 @@ INSERT INTO commerce_config (cg_id,                    cg_value, cg_name,
 VALUES                      ('disp_product_count',     '10',     '商品一覧表示項目数',           14);
 INSERT INTO commerce_config (cg_id,                    cg_value, cg_name,                        cg_index)
 VALUES                      ('decrement_view_stock_count',              '1',      '注文時の表示在庫数デクリメント',               15);
+INSERT INTO commerce_config (cg_id,                     cg_value, cg_name,                        cg_index)
+VALUES                      ('permit_non_member_order', '0',      '非会員からの注文受付',         16);
 
 -- 単位マスター
 DROP TABLE IF EXISTS unit_type;
@@ -656,12 +658,13 @@ CREATE TABLE sale_status (
 ) TYPE=innodb;
 
 -- 商品注文書トラン
-DROP TABLE IF EXISTS `order_sheet`;
-CREATE TABLE `order_sheet` (
+DROP TABLE IF EXISTS order_sheet;
+CREATE TABLE order_sheet (
     oe_serial            INT            AUTO_INCREMENT,                              -- レコードシリアル番号
     oe_user_id           INT            DEFAULT 0                     NOT NULL,      -- 対象ユーザ
     oe_language_id       VARCHAR(2)     DEFAULT ''                    NOT NULL,      -- 受注言語
     
+    oe_client_id         CHAR(32)       DEFAULT ''                    NOT NULL,      -- クライアントID
     oe_custm_id          INT            DEFAULT 0                     NOT NULL,      -- 得意先(顧客)ID(参照用)、会員情報のときは-を付ける
     oe_custm_name        VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- 得意先(顧客)名
     oe_custm_name_kana   VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- 得意先(顧客)名(カナ)
@@ -673,6 +676,7 @@ CREATE TABLE `order_sheet` (
     oe_custm_address2    VARCHAR(60)    DEFAULT ''                    NOT NULL,      -- ビル・マンション名等
     oe_custm_phone       VARCHAR(30)    DEFAULT ''                    NOT NULL,      -- 電話番号
     oe_custm_fax         VARCHAR(30)    DEFAULT ''                    NOT NULL,      -- FAX
+    oe_custm_email       VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- Eメールアドレス
     oe_custm_country_id  VARCHAR(3)     DEFAULT ''                    NOT NULL,      -- 国ID
     
     oe_deliv_id          INT            DEFAULT 0                     NOT NULL,      -- 出荷先ID(参照用)
@@ -686,6 +690,7 @@ CREATE TABLE `order_sheet` (
     oe_deliv_address2    VARCHAR(60)    DEFAULT ''                    NOT NULL,      -- ビル・マンション名等
     oe_deliv_phone       VARCHAR(30)    DEFAULT ''                    NOT NULL,      -- 電話番号
     oe_deliv_fax         VARCHAR(30)    DEFAULT ''                    NOT NULL,      -- FAX
+    oe_deliv_email       VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- Eメールアドレス
     oe_deliv_country_id  VARCHAR(3)     DEFAULT ''                    NOT NULL,      -- 国ID
 
     oe_bill_id           INT            DEFAULT 0                     NOT NULL,      -- 請求先ID(参照用)
@@ -699,6 +704,7 @@ CREATE TABLE `order_sheet` (
     oe_bill_address2     VARCHAR(60)    DEFAULT ''                    NOT NULL,      -- ビル・マンション名等
     oe_bill_phone        VARCHAR(30)    DEFAULT ''                    NOT NULL,      -- 電話番号
     oe_bill_fax          VARCHAR(30)    DEFAULT ''                    NOT NULL,      -- FAX
+    oe_bill_email        VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- Eメールアドレス
     oe_bill_country_id   VARCHAR(3)     DEFAULT ''                    NOT NULL,      -- 国ID
 
     oe_deliv_method_id   VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- 配送方法
@@ -750,6 +756,7 @@ CREATE TABLE order_header (
     or_custm_address2    VARCHAR(60)    DEFAULT ''                    NOT NULL,      -- ビル・マンション名等
     or_custm_phone       VARCHAR(30)    DEFAULT ''                    NOT NULL,      -- 電話番号
     or_custm_fax         VARCHAR(30)    DEFAULT ''                    NOT NULL,      -- FAX
+    or_custm_email       VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- Eメールアドレス
     or_custm_country_id  VARCHAR(3)     DEFAULT ''                    NOT NULL,      -- 国ID
     
     or_deliv_id          INT            DEFAULT 0                     NOT NULL,      -- 出荷先ID(参照用)
@@ -763,6 +770,7 @@ CREATE TABLE order_header (
     or_deliv_address2    VARCHAR(60)    DEFAULT ''                    NOT NULL,      -- ビル・マンション名等
     or_deliv_phone       VARCHAR(30)    DEFAULT ''                    NOT NULL,      -- 電話番号
     or_deliv_fax         VARCHAR(30)    DEFAULT ''                    NOT NULL,      -- FAX
+    or_deliv_email       VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- Eメールアドレス
     or_deliv_country_id  VARCHAR(3)     DEFAULT ''                    NOT NULL,      -- 国ID
 
     or_bill_id           INT            DEFAULT 0                     NOT NULL,      -- 請求先ID(参照用)
@@ -776,6 +784,7 @@ CREATE TABLE order_header (
     or_bill_address2     VARCHAR(60)    DEFAULT ''                    NOT NULL,      -- ビル・マンション名等
     or_bill_phone        VARCHAR(30)    DEFAULT ''                    NOT NULL,      -- 電話番号
     or_bill_fax          VARCHAR(30)    DEFAULT ''                    NOT NULL,      -- FAX
+    or_bill_email        VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- Eメールアドレス
     or_bill_country_id   VARCHAR(3)     DEFAULT ''                    NOT NULL,      -- 国ID
 
     or_deliv_method_id   VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- 配送方法
