@@ -8,16 +8,19 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: ec_mainWidgetContainer.php 159 2008-01-18 02:19:50Z naoki $
+ * @version    SVN: $Id: ec_mainWidgetContainer.php 1583 2009-03-16 04:16:39Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
+require_once($gEnvManager->getCurrentWidgetDbPath() . '/ec_mainDb.php');
 
 class ec_mainWidgetContainer extends BaseWidgetContainer
 {
+	private $mainDb;	// DB接続オブジェクト
 	const SES_KEY_AGREE_MEMBER = 'agree_member';		// 会員規約に同意したかどうかのセッションキー
+	const CF_PERMIT_NON_MEMBER_ORDER = 'permit_non_member_order';			// 非会員の購入許可
 	
 	/**
 	 * コンストラクタ
@@ -26,6 +29,8 @@ class ec_mainWidgetContainer extends BaseWidgetContainer
 	{
 		// 親クラスを呼び出す
 		parent::__construct();
+		
+		$this->mainDb = new ec_mainDb();
 	}
 	/**
 	 * ディスパッチ処理(メインコンテナのみ実行)
@@ -39,29 +44,67 @@ class ec_mainWidgetContainer extends BaseWidgetContainer
 	 */
 	function _dispatch($request, &$param)
 	{
-		global $gLaunchManager;
-		global $gEnvManager;
-
 		// 実行処理を決定
 		$task = $request->trimValueOf(M3_REQUEST_PARAM_OPERATION_TASK);
 		if (empty($task)) $task = 'product';
 
 		// ##### アクセス制御 #####
-		// ログインが必要な処理の場合は、ログイン状況をチェックする
-		switch ($task){
-			case 'delivery';		// 配送
-			case 'payment';			// 支払い
-			case 'confirm';			// 確認
-			case 'complete';		// 手続き完了
-			case 'member';			// 会員情報変更
-			case 'changepwd';			// パスワード変更
-			case 'orderhistory';			// 注文履歴
-				// ログイン状態を取得
-				$userInfo = $gEnvManager->getCurrentUserInfo();
-				if (is_null($userInfo)){		// ログインされていない場合
-					$this->SetMsg(0, "ログインが必要です");
-					return true;
-				}
+		$canNonMemberOrder = $this->mainDb->getConfig(self::CF_PERMIT_NON_MEMBER_ORDER);
+		if (empty($canNonMemberOrder)){			// 会員のみ注文が可能なとき
+			// ログインが必要な処理の場合は、ログイン状況をチェックする
+			switch ($task){
+				case 'order';			// 注文開始
+				case 'regcustomer';			// 購入者情報入力
+				case 'delivery';		// 配送先入力
+				case 'payment';			// 支払い
+				case 'confirm';			// 確認
+				case 'complete';		// 手続き完了
+				case 'member';			// 会員情報変更
+				case 'changepwd';			// パスワード変更
+				case 'orderhistory';			// 注文履歴
+					// ログイン状態を取得
+					/*$userInfo = $this->gEnv->getCurrentUserInfo();
+					if (is_null($userInfo)){		// ログインされていない場合
+						$this->SetMsg(0, "ログインが必要です");
+						return true;
+					}*/
+					if (!$this->gEnv->isCurrentUserLogined()){		// ログインされていない場合
+						$this->SetMsg(0, "ログインが必要です");
+						return true;
+					}
+			}
+		} else {
+			// ログインが必要な処理の場合は、ログイン状況をチェックする
+			switch ($task){
+				case 'member';			// 会員情報変更
+				case 'changepwd';		// パスワード変更
+				case 'orderhistory';	// 注文履歴
+					// ログイン状態を取得
+					/*$userInfo = $this->gEnv->getCurrentUserInfo();
+					if (is_null($userInfo)){		// ログインされていない場合
+						$this->SetMsg(0, "ログインが必要です");
+						return true;
+					}*/
+					if (!$this->gEnv->isCurrentUserLogined()){		// ログインされていない場合
+						$this->SetMsg(0, "ログインが必要です");
+						return true;
+					}
+			}
+		}
+		
+		// ##### 遷移先を決定 #####
+		if ($task == 'order'){
+			if ($this->gEnv->isCurrentUserLogined()){		// ユーザがログインしている場合(会員の場合)
+				// 注文の画面遷移(配送先入力→支払い方法入力→確認)
+				$orderPage = $this->gEnv->createCurrentPageUrl() . '&task=delivery';// 配送先入力
+				$this->gPage->redirect($orderPage);
+				return true;
+			} else {			// 非会員の購入の場合
+				// 注文の画面遷移(購入者情報入力→配送先入力→支払い方法入力→確認)
+				$orderPage = $this->gEnv->createCurrentPageUrl() . '&task=regcustomer';// 購入者情報入力
+				$this->gPage->redirect($orderPage);
+				return true;
+			}
 		}
 		
 		// 会員規約を承認していない場合は、規約ページへ遷移
@@ -75,6 +118,7 @@ class ec_mainWidgetContainer extends BaseWidgetContainer
 			case 'cart';			// カート機能
 			case 'login';			// 会員ログイン
 			case 'regmember';			// 会員登録
+			case 'regcustomer';			// 購入者情報入力
 			case 'delivery';		// 配送
 			case 'payment';			// 支払い
 			case 'confirm';			// 確認
@@ -84,7 +128,7 @@ class ec_mainWidgetContainer extends BaseWidgetContainer
 			case 'agreemember';		// 会員規約表示
 			case 'changepwd';			// パスワード変更
 			case 'orderhistory';			// 注文履歴
-				$gLaunchManager->goSubWidget($task);
+				$this->gLaunch->goSubWidget($task);
 				return false;
 			default:
 				$this->SetMsg(0, "画面が見つかりません");
@@ -107,6 +151,8 @@ class ec_mainWidgetContainer extends BaseWidgetContainer
 
 		// 要求画面によってテンプレートを変更
 		switch ($task){
+			case 'order';			// 注文開始
+			case 'regcustomer';			// 購入者情報入力
 			case 'delivery';		// 配送
 			case 'payment';			// 支払い
 			case 'confirm';			// 確認
@@ -131,12 +177,12 @@ class ec_mainWidgetContainer extends BaseWidgetContainer
 	 */
 	function _assign($request, &$param)
 	{
-		global $gEnvManager;
-		
 		$task = $request->trimValueOf(M3_REQUEST_PARAM_OPERATION_TASK);
 
 		// 要求画面によってテンプレートを変更
 		switch ($task){
+			case 'order';			// 注文開始
+			case 'regcustomer';			// 購入者情報入力
 			case 'delivery';		// 配送
 			case 'payment';			// 支払い
 			case 'confirm';			// 確認
@@ -145,7 +191,7 @@ class ec_mainWidgetContainer extends BaseWidgetContainer
 			case 'changepwd';			// パスワード変更
 			case 'orderhistory';			// 注文履歴
 				// ログインが必要であるメッセージを表示
-				$this->tmpl->addVar("_widget", "login_url", $gEnvManager->createCurrentPageUrl() . '&task=login');		// ログイン用URL
+				$this->tmpl->addVar("_widget", "login_url", $this->gEnv->createCurrentPageUrl() . '&task=login');		// ログイン用URL
 			default:
 		}
 	}
